TtsLengthException class

Exception thrown when TTS text exceeds safe duration limits.

Implemented types

Constructors

TtsLengthException(String text, double estimatedSeconds, String message)
Creates a length exception with details.
const

Properties

estimatedSeconds double
Estimated duration in seconds.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable explanation.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The text that was too long.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited